@@ -116,7 +116,7 @@ quiet=FALSE,
 progbar=!quiet,
 browse=FALSE,
 read=TRUE,
-meta=substr(file, nchar(file)-3, 1e4)==".txt",
+meta=grepl('.txt$', file),
 fread=FALSE,
 format=NA,
 ntrunc=2,
